/* $XFree86: $ */

/*
 *----------------------------------------------------------------------------
 * Filename: portctl.h
 * $Revision: 1.12 $
 *----------------------------------------------------------------------------
 *
 * Copyright (c) Intel Corporation (2003 - 2005).
 *
 * The source code contained or described herein and all documents
 * related to the source code ("Material") are owned by Intel
 * Corporation or its suppliers or licensors.  Title to the Material
 * remains with Intel Corporation or it suppliers and licensors.  The
 * Material contains trade secrets and proprietary and confidential 
 * information of Intel or its suppliers and licensors.  The Material is
 * protected by worldwide copyright and trade secret laws and
 * treaty provisions.  No part of the Material may be used, copied,
 * reproduced, modified, published, uploaded, posted, transmitted,
 * distributed, or disclosed in any way without Intels prior express
 * written permission.
 *
 * No license under any patent, copyright, trade secret or other
 * intellectual property right is granted to or conferred upon you by
 * disclosure or delivery of the Materials, either expressly, by
 * implication, inducement, estoppel or otherwise.  Any license
 * under such intellectual property rights must be express
 * and approved by Intel in writing.
 *
 * File Description:
 *   Include file for protocol and client library
 *
 *----------------------------------------------------------------------------
 * Functions:
 * 
 *----------------------------------------------------------------------------
 * Authors:
 *  Bob Paauwe <bob.j.paauwe@intel.com>
 *
 *----------------------------------------------------------------------------
 */
/* $Xorg: Exp $ */

/* THIS IS NOT AN X CONSORTIUM STANDARD OR AN X PROJECT TEAM SPECIFICATION */

#ifndef _INTELPORTCTL_H_
#define _INTELPORTCTL_H_

#include <X11/Xfuncproto.h>
#include <X11/Xmd.h>

#define X_INTELPortCtlQueryVersion	        0
#define X_INTELPortCtlSetClientVersion	   	1
#define X_INTELPortCtlGetPortAttributes    	2
#define X_INTELPortCtlSetPortAttributes    	3
#define X_INTELPortCtlPortControl          	4
#define X_INTELPortCtlQueryPorts           	5
#define X_INTELPortCtlReadPortAttributes   	6
#define X_INTELPortCtlWritePortAttributes  	7
#define X_INTELPortCtlGetPortMode          	8
#define X_INTELPortCtlSetPortMode          	9
#define X_INTELPortCtlAllocPort           	10
#define X_INTELPortCtlGetPortModes        	11
#define X_INTELPortCtlQueryPort           	12
#define X_INTELPortCtlGetDisplayCapability      13

#ifndef _PORTCTL_SERVER_

#define INTEL_PORT_FREE				0xFFFFFFFF
#define INTEL_PORT_ANY              0x0000F000
#define INTEL_PORT_ANALOG           0x00001000
#define INTEL_PORT_DIGITAL          0x00002000
#define INTEL_PORT_LVDS             0x00004000 
#define INTEL_PORT_RGBA             0x00008000 /* Enhanced DVO */

/* Port flags */
/* port status port_type1 */
/* Do we need this here?
 * Slave is twin mode for the port
 * Master is clone as well? 
 */
#define INTEL_PORT_UNAVAILABLE 0x00000000
#define INTEL_PORT_ENABLED 0x00000001
#define INTEL_PORT_SLAVE   0x00000002
#define INTEL_PORT_CLONE   0x00000004
#define INTEL_PORT_MASTER  0x80000000

/* port status port_type2 */
/* refer to dsp_alm.c, dsp_wht.c.. etc */
/* one of the following :
   0x00000001 = DVO(815), DVO-A(830),    Int-TV(Alviso)
   0x00000002 = CRT(815), DVO-B(Alm),    DVO-B(Napa)
   0x00000003 =           DVO-C(Alm),    DVO-B(Napa)         
   0x00000004 =           Int-LVDS(855), Int-LVDS(Alviso)
   0x00000005 =           CRT (Alm),     CRT (Napa)      */ 

typedef struct _port_config {
	unsigned long port_assignment; /* }                                   */
	unsigned long port_enabled;    /* }---> Refer to port configuration   */
	unsigned long port_type1;      /* }     information definitions above */
	unsigned long port_type2;      /* }                                   */
} port_config_t;

/* Multi-Display-Flags used as                      */
/*           1.(bit-wise OR'ed) capability bits     */
/*           2.(exclusive) status bits              */
/*           3.(exclusive) set-dsp-config commands  */
#define MULTI_TYPE_SINGLE      0x1
#define MULTI_TYPE_CLONE       0x2
#define MULTI_TYPE_TWIN        0x4
#define MULTI_TYPE_EXTENDED    0x8

typedef struct _INTELPortCtlConfigInfo {
	unsigned long config_id;        /* Configuration Id        */
	unsigned long multi_dsp_caps;   /* Refer to Multi-Display-Flags above*/
	unsigned long multi_dsp_status; /* Refer to Multi-Display-Flags above*/
	port_config_t port_config_list[4]; /* refer to esc_port_config_t */
}INTELPortCtlConfigInfo;

typedef struct {
	unsigned long id;	/* Attribute ID (see ID list for known attributes */
	unsigned long type;	/* range, list, boolean */
	char name[32];		/* Attribute name */
	unsigned long flags;
	union _default {
		unsigned long _pad0;
		unsigned long default_value;
		unsigned long default_index;
		unsigned long value;
	} def;
	union _current {
		unsigned long _pad1;
		unsigned long current_value;
		unsigned long current_index;
	} current;
	union _min {
		unsigned long _pad2;
		unsigned long min;
		unsigned long num_entries;
	} min;
	union _max {
		unsigned long _pad3;
		unsigned long max;
	} max;
	union _step {
		unsigned long _pad4;
		unsigned long step;
	} step;
} INTELPortCtlAttribute;

typedef struct {
	int  width;
	int  height;
	int  h_sync_start;
	int  h_sync_end;
	int  h_total;
	int  v_sync_start;
	int  v_sync_end;
	int  v_total;
	int	v_refresh;
	unsigned long    flags;
} INTELPortCtlTimingInfoRec, *INTELPortCtlTimingInfoPtr;




_XFUNCPROTOBEGIN

Bool IntelPortCtlQueryVersion(
    Display*	/* dpy */,
    int*		/* majorVersion */,
    int*		/* minorVersion */
);

Bool IntelPortCtlQueryExtension(
    Display*	/* dpy */,
    int*		/* event_base */,
    int*		/* error_base */
);

Bool IntelPortCtlSetClientVersion(
    Display*	/* dpy */
);

Bool IntelPortCtlGetPortAttributes(
    Display*	/* dpy */,
    int			/* screen */,
	int			/* port */,
    INTELPortCtlAttribute**	/* Attributes */,
	unsigned short*			/* number of attributes */
);

Bool IntelPortCtlSetPortAttributes(
    Display*	/* dpy */,
    int			/* screen */,
	int			/* port */,
    INTELPortCtlAttribute**	/* Attributes */,
	unsigned short			/* number of attributes */
);

Bool IntelPortCtlPortControl(
    Display*	/* dpy */,
    int			/* screen */,
    int         /* port */,
	int			/* mode */
);

Bool IntelPortCtlQueryPorts(
    Display*	/* dpy */,
    int			/* screen */,
    int*		/* Allocated ports */
);

Bool IntelPortCtlGetPortMode(
    Display*			/* dpy */,
    int					/* screen */,
    int					/* port */,
	INTELPortCtlTimingInfoPtr	/* mode pointer */
);

Bool IntelPortCtlGetPortModes(
    Display*			/* dpy */,
    int					/* screen */,
    int					/* port */,
	int*				/* number of modes */,
	INTELPortCtlTimingInfoPtr*	/* mode pointer */
);

Bool IntelPortCtlSetPortMode(
    Display*		/* dpy */,
    int				/* screen */,
    int				/* port */,
	int				/* fix_fb */,
	INTELPortCtlTimingInfoPtr /* mode pointer */
);

Bool IntelPortCtlAllocPort(
    Display*		/* dpy */,
    int				/* screen */,
    int				/* port */,
	int				/* mode */,
	unsigned long	/* flags/port_type */
);

Bool IntelPortCtlQueryPort(
	Display*	/* dpy */,
    	int		/* screen */,
    	int		/* port */,
	unsigned long*	/* port_type */,
	unsigned long*	/* port_status */,
	unsigned long*  /* port_type2 */
);

Bool IntelPortCtlGetDisplayCapability(
	Display*	/* dpy */,
    	int		/* screen */,
    	int		/* rw */,
	unsigned long*	/* capability */,
	unsigned long*	/* status */
);

Bool IntelPortCtlGetDisplayConfig(
    Display* /*dpy*/,
    INTELPortCtlConfigInfo* /* Struct holding Info of ports */    
);

Bool IntelPortCtlSetMultiDisplay(
     Display* /*dpy*/,
     unsigned long multi_dsp_config

);

_XFUNCPROTOEND

#endif

#endif
